/*
 * gcc -o factorize -I/opt/local/include factorize.c -L/opt/local/lib -lgmp
 *
 * echo 123456789077 | ./factorize
 * echo 73786976294838206464 | ./factorize
 */

#include <stdio.h>
#include <stdint.h>
#include <stdlib.h>
#include <string.h>
#include <inttypes.h>
#include <errno.h>
#include <gmp.h>

#define _POSIX_C_SOURCE 200809L

static void factorize_uint64(uint64_t number)
{
    uint64_t i, n = number;

    (void) printf("%" PRIu64, number);
    for (i = 2; i <= n; i++) {
	while ((n % i) == 0) {
	    (void) printf("%s%" PRIu64, (n != number) ? " * " : " = ", i);
	    (void) fflush(stdout);
	    n = n / i;
	}
    }
    (void) puts("");
}

static void factorize_mpz(mpz_t number)
{
    mpz_t n, i, r;
    mpz_inits(n, i, r, NULL);
    mpz_set(n, number);
    
    (void) mpz_out_str(stdout, 10, number);
    for (mpz_set_ui(i, 2); mpz_cmp(i, n) <= 0; mpz_add_ui(i, i, 1)) {
        for(mpz_mod(r, n, i); mpz_cmp_ui(r, 0) == 0; mpz_mod(r, n, i)) {
	    (void) printf((mpz_cmp(n, number) != 0) ? " * " : " = ");
	    (void) mpz_out_str(stdout, 10, i);
	    (void) fflush(stdout);
	    mpz_divexact(n, n, i);
	}
    }
    (void) puts("");
    mpz_clears(n, i, r, NULL);
}

int main(int argc, char *argv[])
{
    char line[1024];
    const char *delim = " \t\n";
    char *word;

    uint64_t num;
    mpz_t number;
    mpz_init(number);

    while (fgets(line, sizeof(line), stdin)) {
	for (word = strtok(line, delim); word; word = strtok(NULL, delim)) {
	    errno = 0;
	    num = strtoull(word, NULL, 10);
	    if (errno == 0) {
		factorize_uint64(num);
	    } else if (mpz_set_str(number, word, 10) == 0) {
		factorize_mpz(number);
	    }
	}
    }
    mpz_clear(number);

    return 0;
}
